lilypondparsertools.SyntaxNode
==============================

.. abjad-lineage:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode

.. autoclass:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__eq__
      ~abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__getitem__
      ~abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__len__
      ~abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__ne__
      ~abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__repr__
      ~abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__str__
   :noindex:
